@@ -6,6 +6,7 @@ Created on Fri Aug 24 12:47:19 2018
 """
 import numpy as np
 #from w2l import activation_functions
+#from surrogates import math_utils
 from hipersim.surrogates import math_utils
 
 class ann:
@@ -326,8 +327,11 @@ class ann:
         if self.output_style == 'Verbose':
             print('Verbose output')
         elif self.output_style == 'Plot':
+            import tkinter
+            import matplotlib            
             import matplotlib.pyplot as plt
             plt.ion()
+            matplotlib.use('TkAgg')
             fig, axs = plt.subplots(1,2,figsize = (8,4))
             plt00 = axs[0].plot(0,0,'-k')[0]
             plt01 = axs[0].plot(0,0,'-r')[0]
